{ config, libs, pkgs, ... }:

{
  imports = [                   # applications :
    ./app-adminsys.nix          # pour gérer le système dans son ensemble et les services
    ./app-bureautique.nix       # dédiée à la bureautique (traitement de texte, dessin, ...)
    ./app-cao.nix               # de conception assisté par ordinateur & modélisation
    ./app-client-internet.nix   # pour accéder & utiliser des ressources par le réseau
    ./app-dev.nix               # utilisée pour développer des programmes/scripts
    ./app-multimedia.nix        # pour gérer le son, l'image et la vidéo
    ./app-network.nix           # de gestion, de diagnostique & surveillance réseau 
  ];

  environment.systemPackages = with pkgs; [
    cowsay
    curlftpfs
    docker
    espeak
    gcc # pour les appels depuis les scripts
    gnome3.seahorse
    gnuplot
    gpm
    inotify-tools
    jekyll
    josm
    linuxPackages.virtualbox
    linuxPackages.virtualboxGuestAdditions
    lz4
    lzop
    pass
    pgadmin
    postfix
    pwgen
    sakura
    samba
    slock # cannot disable the out-of-memory killer for this process (make sure to suid or sgid slock) --> en root
    spaceFM
    sqlitebrowser
    sshfsFuse
    taskwarrior
    transmission_gtk
    transmission_remote_gtk
    udevil
    unbound
    unetbootin
    urbanterror
    vbindiff
    vifm
    viking
    wmname
    yubikey-personalization-gui
  ];

  nixpkgs.config.packageOverrides = pkgs: {
    clawsMail = pkgs.clawsMail.override { enablePluginFancy = true; };
    mumble = pkgs.mumble.override { pulseSupport = true; };
  };

  # Enable the X11 windowing system.
  services.xserver = {
    enable = true;
    layout = "fr";
    xkbOptions = "eurosign:e";
    displayManager.lightdm.enable = true;
    windowManager.awesome.enable = true;
    startGnuPGAgent = true;
    startOpenSSHAgent = false; # pas compatible avec l'agent GnuPG
    inputClassSections = [''
    Identifier  "Marble Mouse"
    MatchProduct "Logitech USB Trackball"
    MatchIsPointer "on"
    MatchDevicePath "/dev/input/event*"
    Driver "evdev"
    # Physical button #s:     A b D - - - - B C    b = A & D simultaneously;   - = no button
    #Option "ButtonMapping" "1 8 3 4 5 6 7 2 2"   #  For right-hand placement
    #Option "ButtonMapping" "3 8 1 4 5 6 7 2 2"   #  For left-hand placement

    # EmulateWheel refers to emulating a mouse wheel using Marble Mouse trackball.
    Option "EmulateWheel" "true"
    Option "EmulateWheelButton" "8"   # Factory default; use "9" for left-side placement.

    # EmulateWheelInertia specifies how far (in pixels) the pointer must move to
    # generate button press/release events in wheel emulation mode.
    Option "EmulateWheelInertia" "10" # Factory default: 50

    Option "ZAxisMapping" "4 5"
    Option "XAxisMapping" "6 7"       # Disable this for vertical-only scrolling.
    # Emulate3Buttons refers to the act of pressing buttons A and D
    # simultaneously to emulate a middle-click or wheel click.
    Option "Emulate3Buttons" "true"   # Factory default.
    ''];
  };

  hardware.pulseaudio = {
    enable = true;
    support32Bit = true;
  };
  environment.etc."pulse/daemon.conf".text = "flat-volumes = no";
  nixpkgs.config.allowUnfree = true;
}
